==> piwigo_2.2.2.orig.tar.gz: piwigo/language/da_DK/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Installation';
$lang['Basic configuration'] = 'Basic konfiguration';
$lang['Default gallery language'] = 'Default galleri sprog';
$lang['Database configuration'] = 'Database konfiguration';
$lang['Admin configuration'] = 'Admin konfiguration';
$lang['Start Install'] = 'Start Installation';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'mail addresse skal være som xxx@yyy.eee (example : jack@altern.org)';
$lang['Webmaster login'] = 'Webmaster login';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Det vil blive vist til de besøgende. Det er nødvendigt for website administration';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Forbindelse til server oprettet, men det var ikke muligt at forbinde til databasen';
$lang['Can\'t connect to server'] = 'Kan ikke forbinde til serveren';
$lang['Host'] = 'MySQL host';
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = 'localhost, sql.multimania.com, toto.freesurf.fr';
$lang['User'] = 'Bruger';
$lang['user login given by your host provider'] = 'bruger login som du har fra din udbyder';
$lang['Password'] = 'Password';
$lang['user password given by your host provider'] = 'bruger password som du har fra din udbyder';
$lang['Database name'] = 'Database navn';
$lang['also given by your host provider'] = 'som du også har fået af din udbyder';
$lang['Database table prefix'] = 'Database tabel prefix';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'database tabel navne vil være forvalgt (giver dig bedre mulighed for at administrere tabellerne)';
$lang['enter a login for webmaster'] = 'indtast et login  webmaster';
$lang['webmaster login can\'t contain characters \' or "'] = 'webmaster login må ikke indeholde karakterernecan \' or "';
$lang['please enter your password again'] = 'indtast dit password igen';
$lang['Webmaster password'] = 'Webmaster password';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Hold det hemmeligt, det giver dig adgang til administrations panelet.';
$lang['Password [confirm]'] = 'Password [bekræft]';
$lang['verification'] = 'bekræftelse';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Hjælp ? Stil dine spørgsmål på <a href="%s">Piwigo message board</a>.';
$lang['Webmaster mail address'] = 'Webmaster mail addresse';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Besøgende vil have mulighed for at kontakte administratoren med denne mail';

$lang['PHP 5 is required'] = 'PHP 5 er nødvendig';
$lang['It appears your webhost is currently running PHP %s.'] = 'Din webhost har PHP %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo kan prøve at skifte din konfiguration til PHP 5 ved at oprette eller ændre en. htaccess fil.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Bemærk at du kan ændre din konfiguration selv og derefter genstarte Piwigo.';
$lang['Try to configure PHP 5'] = 'Prøv at konfigurere PHP 5';
$lang['Sorry!'] = 'Hov!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo var ikke istand til af konfigurere PHP 5.';
$lang["You may referer to your hosting provider's support and see how you could switch to PHP 5 by yourself."] = "Du henvises til din webhost for at se hvordan du selv kan skifte til PHP 5.";
$lang['Hope to see you back soon.'] = 'Håber snart at se dig igen.';

$lang['Database type'] = 'Database type';
$lang['The type of database your piwigo data will be store in'] = 'Din Piwigo database vil blive lagret i';
$lang['Congratulations, Piwigo installation is completed'] = 'Tillykke, Piwigo installationen er slut';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'En alternativ måde er at kopiere teksten i boksen ovenover og sætte den ind i filen "local/config/database.inc.php" (Advarsel : database.inc.php må kun indeholde hvad der er i tekstfeltet, ingen linieskift eller andet.)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Oprettelsen af local/config/database.inc.php gik galt.';
$lang['Download the config file'] = 'Download config filen';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Du kan downloade config filen og uploade den til local/config i din installation.';
$lang['SQLite and PostgreSQL are currently in experimental state.'] = 'SQLite og PostgreSQL er i øjeblikket kun som eksperiment.';
$lang['Learn more'] = 'Lær mere';
?>

==> piwigo_2.3.1.orig.tar.gz: piwigo/language/da_DK/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Installation';
$lang['Basic configuration'] = 'Basic konfiguration';
$lang['Default gallery language'] = 'Default galleri sprog';
$lang['Database configuration'] = 'Database konfiguration';
$lang['Admin configuration'] = 'Admin konfiguration';
$lang['Start Install'] = 'Start Installation';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'mail addresse skal være som xxx@yyy.eee (example : jack@altern.org)';
$lang['Webmaster login'] = 'Webmaster login';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Det vil blive vist til de besøgende. Det er nødvendigt for website administration';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Forbindelse til server oprettet, men det var ikke muligt at forbinde til databasen';
$lang['Can\'t connect to server'] = 'Kan ikke forbinde til serveren';
$lang['Host'] = 'MySQL host';
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = 'localhost, sql.multimania.com, toto.freesurf.fr';
$lang['User'] = 'Bruger';
$lang['user login given by your host provider'] = 'bruger login som du har fra din udbyder';
$lang['Password'] = 'Password';
$lang['user password given by your host provider'] = 'bruger password som du har fra din udbyder';
$lang['Database name'] = 'Database navn';
$lang['also given by your host provider'] = 'som du også har fået af din udbyder';
$lang['Database table prefix'] = 'Database tabel prefix';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'database tabel navne vil være forvalgt (giver dig bedre mulighed for at administrere tabellerne)';
$lang['enter a login for webmaster'] = 'indtast et login  webmaster';
$lang['webmaster login can\'t contain characters \' or "'] = 'webmaster login må ikke indeholde karakterernecan \' or "';
$lang['please enter your password again'] = 'indtast dit password igen';
$lang['Webmaster password'] = 'Webmaster password';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Hold det hemmeligt, det giver dig adgang til administrations panelet.';
$lang['Password [confirm]'] = 'Password [bekræft]';
$lang['verification'] = 'bekræftelse';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Hjælp ? Stil dine spørgsmål på <a href="%s">Piwigo message board</a>.';
$lang['Webmaster mail address'] = 'Webmaster mail addresse';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Besøgende vil have mulighed for at kontakte administratoren med denne mail';
$lang['PHP 5 is required'] = 'PHP 5 er nødvendig';
$lang['It appears your webhost is currently running PHP %s.'] = 'Din webhost har PHP %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo kan prøve at skifte din konfiguration til PHP 5 ved at oprette eller ændre en. htaccess fil.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Bemærk at du kan ændre din konfiguration selv og derefter genstarte Piwigo.';
$lang['Try to configure PHP 5'] = 'Prøv at konfigurere PHP 5';
$lang['Sorry!'] = 'Hov!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo var ikke istand til af konfigurere PHP 5.';
$lang["You may referer to your hosting provider's support and see how you could switch to PHP 5 by yourself."] = "Du henvises til din webhost for at se hvordan du selv kan skifte til PHP 5.";
$lang['Hope to see you back soon.'] = 'Håber snart at se dig igen.';
$lang['Congratulations, Piwigo installation is completed'] = 'Tillykke, Piwigo installationen er slut';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'En alternativ måde er at kopiere teksten i boksen ovenover og sætte den ind i filen "local/config/database.inc.php" (Advarsel : database.inc.php må kun indeholde hvad der er i tekstfeltet, ingen linieskift eller andet.)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Oprettelsen af local/config/database.inc.php gik galt.';
$lang['Download the config file'] = 'Download config filen';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Du kan downloade config filen og uploade den til local/config i din installation.';
$lang['Just another Piwigo gallery'] = 'Bare et andet Piwigo galleri';
$lang['Welcome to my photo gallery'] = 'Velkommen til mit photo galleri';

?>
